@@ -30,10 +30,12 @@ def get_qa_projects():
 
 
 def qainit_deploy(args):
+    with open(f"{qainit_dir}/suitepy-projects.yml", "w+") as file:
+        file.write(args)
+
     return subprocess.run(
-        # development only
-        # [twig_command, "suite", "deploy", args],
-        ["twig", "feature", "suite", "deploy", args],
+        # [twig_command, "suite", "deploy"], # development only
+        ["twig", "feature", "suite", "deploy"],
         cwd=qainit_dir,
         check=True,
     )
